IndicScriptListConversion extension
Methods
-
toCanonicalDevanagariFromGujarati(
{IndicScriptConversionOptions options = const IndicScriptConversionOptions()}) → List< String> -
Available on Iterable<
Converts each Gujarati string in the collection to canonical Devanagari.String> , provided by the IndicScriptListConversion extension -
toCanonicalGujaratiFromDevanagari(
{IndicScriptConversionOptions options = const IndicScriptConversionOptions()}) → List< String> -
Available on Iterable<
Converts each Devanagari string in the collection to canonical Gujarati.String> , provided by the IndicScriptListConversion extension -
toCanonicalIastFromDevanagari(
{ScriptToIastOptions options = const ScriptToIastOptions()}) → List< String> -
Available on Iterable<
Converts each Devanagari string in the collection back to canonical IAST.String> , provided by the IndicScriptListConversion extension -
toCanonicalIastFromGujarati(
{ScriptToIastOptions options = const ScriptToIastOptions()}) → List< String> -
Available on Iterable<
Converts each Gujarati string in the collection back to canonical IAST.String> , provided by the IndicScriptListConversion extension -
toDevanagari(
{IastToDevanagariOptions options = const IastToDevanagariOptions()}) → List< TransliterationResult> -
Available on Iterable<
Translates each IAST string in the collection to Devanagari returning a List of TransliterationResult objects.String> , provided by the IndicScriptListConversion extension -
toDevanagariFromGujarati(
{IndicScriptConversionOptions options = const IndicScriptConversionOptions()}) → List< String> -
Available on Iterable<
Converts each Gujarati string in the collection to Devanagari with exact source metadata recovery.String> , provided by the IndicScriptListConversion extension -
toDevanagariFromIast(
{IastToDevanagariOptions options = const IastToDevanagariOptions()}) → List< String> -
Available on Iterable<
Converts each IAST string in the collection to Devanagari script strings.String> , provided by the IndicScriptListConversion extension -
toExactDevanagariFromGujarati(
) → List< String> -
Available on Iterable<
Recovers exact original Devanagari from each Gujarati string in the collection.String> , provided by the IndicScriptListConversion extension -
toExactGujaratiFromDevanagari(
) → List< String> -
Available on Iterable<
Recovers exact original Gujarati from each Devanagari string in the collection.String> , provided by the IndicScriptListConversion extension -
toExactIastFromDevanagari(
) → List< String> -
Available on Iterable<
Recovers exact original IAST from each Devanagari string in the collection.String> , provided by the IndicScriptListConversion extension -
toExactIastFromGujarati(
) → List< String> -
Available on Iterable<
Recovers exact original IAST from each Gujarati string in the collection.String> , provided by the IndicScriptListConversion extension -
toGujarati(
{IastToGujaratiOptions options = const IastToGujaratiOptions()}) → List< TransliterationResult> -
Available on Iterable<
Translates each IAST string in the collection to Gujarati returning a List of TransliterationResult objects.String> , provided by the IndicScriptListConversion extension -
toGujaratiFromDevanagari(
{IndicScriptConversionOptions options = const IndicScriptConversionOptions()}) → List< String> -
Available on Iterable<
Converts each Devanagari string in the collection to Gujarati with exact source metadata recovery.String> , provided by the IndicScriptListConversion extension -
toGujaratiFromIast(
{IastToGujaratiOptions options = const IastToGujaratiOptions()}) → List< String> -
Available on Iterable<
Converts each IAST string in the collection to Gujarati script strings.String> , provided by the IndicScriptListConversion extension -
toIastFromDevanagari(
{ScriptToIastOptions options = const ScriptToIastOptions()}) → List< String> -
Available on Iterable<
Smart converts each Devanagari string in the collection back to IAST (recovers exact source if embedded metadata exists).String> , provided by the IndicScriptListConversion extension -
toIastFromGujarati(
{ScriptToIastOptions options = const ScriptToIastOptions()}) → List< String> -
Available on Iterable<
Smart converts each Gujarati string in the collection back to IAST (recovers exact source if embedded metadata exists).String> , provided by the IndicScriptListConversion extension -
toPlainEnglish(
{IastPlainEnglishOptions options = const IastPlainEnglishOptions()}) → List< TransliterationResult> -
Available on Iterable<
Translates each IAST string in the collection to Plain English returning a List of TransliterationResult objects.String> , provided by the IndicScriptListConversion extension -
toPlainEnglishFromIast(
{IastPlainEnglishOptions options = const IastPlainEnglishOptions()}) → List< String> -
Available on Iterable<
Converts each IAST string in the collection to Plain English strings.String> , provided by the IndicScriptListConversion extension