UnicodeNormalizationForm enum

Normalization applied to the parsing copy or rendered output.

preserve never changes code points. nfc and nfd follow UAX #15 via package:unorm_dart (Unicode 17 data in unorm_dart 0.3.2).

Inheritance
Available extensions

Values

preserve → const UnicodeNormalizationForm
nfc → const UnicodeNormalizationForm
nfd → const UnicodeNormalizationForm

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UnicodeNormalizationForm>
A constant List of the values in this enum, in order of their declaration.