ScriptToIastOptions class

Options for script-to-IAST reverse transliteration.

Constructors

ScriptToIastOptions({UnicodeNormalizationForm inputNormalization = UnicodeNormalizationForm.nfd, UnicodeNormalizationForm outputNormalization = UnicodeNormalizationForm.nfc, bool preserveUnmapped = true, bool preserveEncodedVedicMarks = true})
Creates options for script-to-IAST reverse transliteration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inputNormalization UnicodeNormalizationForm
Input Unicode normalization form.
final
outputNormalization UnicodeNormalizationForm
Output Unicode normalization form.
final
preserveEncodedVedicMarks bool
Whether to preserve encoded Vedic marks in output.
final
preserveUnmapped bool
Whether to preserve unmapped characters in output.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited