ScriptToIastOptions class

Constructors

ScriptToIastOptions({UnicodeNormalizationForm inputNormalization = UnicodeNormalizationForm.nfd, UnicodeNormalizationForm outputNormalization = UnicodeNormalizationForm.nfc, bool preserveUnmapped = true, bool preserveEncodedVedicMarks = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inputNormalization UnicodeNormalizationForm
final
outputNormalization UnicodeNormalizationForm
final
preserveEncodedVedicMarks bool
final
preserveUnmapped bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited