IndicScriptListConversion extension

Extension methods for performing bulk / list transliteration on an Iterable of String items.

on

Methods

toCanonicalDevanagariFromGujarati({IndicScriptConversionOptions options = const IndicScriptConversionOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Converts each Gujarati string in the collection to canonical Devanagari.
toCanonicalGujaratiFromDevanagari({IndicScriptConversionOptions options = const IndicScriptConversionOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Converts each Devanagari string in the collection to canonical Gujarati.
toCanonicalIastFromDevanagari({ScriptToIastOptions options = const ScriptToIastOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Converts each Devanagari string in the collection back to canonical IAST.
toCanonicalIastFromGujarati({ScriptToIastOptions options = const ScriptToIastOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Converts each Gujarati string in the collection back to canonical IAST.
toDevanagari({IastToDevanagariOptions options = const IastToDevanagariOptions()}) List<TransliterationResult>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Translates each IAST string in the collection to Devanagari returning a List of TransliterationResult objects.
toDevanagariFromGujarati({IndicScriptConversionOptions options = const IndicScriptConversionOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Converts each Gujarati string in the collection to Devanagari with exact source metadata recovery.
toDevanagariFromIast({IastToDevanagariOptions options = const IastToDevanagariOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Converts each IAST string in the collection to Devanagari script strings.
toExactDevanagariFromGujarati() List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Recovers exact original Devanagari from each Gujarati string in the collection.
toExactGujaratiFromDevanagari() List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Recovers exact original Gujarati from each Devanagari string in the collection.
toExactIastFromDevanagari() List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Recovers exact original IAST from each Devanagari string in the collection.
toExactIastFromGujarati() List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Recovers exact original IAST from each Gujarati string in the collection.
toGujarati({IastToGujaratiOptions options = const IastToGujaratiOptions()}) List<TransliterationResult>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Translates each IAST string in the collection to Gujarati returning a List of TransliterationResult objects.
toGujaratiFromDevanagari({IndicScriptConversionOptions options = const IndicScriptConversionOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Converts each Devanagari string in the collection to Gujarati with exact source metadata recovery.
toGujaratiFromIast({IastToGujaratiOptions options = const IastToGujaratiOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Converts each IAST string in the collection to Gujarati script strings.
toIastFromDevanagari({ScriptToIastOptions options = const ScriptToIastOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Smart converts each Devanagari string in the collection back to IAST (recovers exact source if embedded metadata exists).
toIastFromGujarati({ScriptToIastOptions options = const ScriptToIastOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Smart converts each Gujarati string in the collection back to IAST (recovers exact source if embedded metadata exists).
toPlainEnglish({IastPlainEnglishOptions options = const IastPlainEnglishOptions()}) List<TransliterationResult>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Translates each IAST string in the collection to Plain English returning a List of TransliterationResult objects.
toPlainEnglishFromIast({IastPlainEnglishOptions options = const IastPlainEnglishOptions()}) List<String>

Available on Iterable<String>, provided by the IndicScriptListConversion extension

Converts each IAST string in the collection to Plain English strings.